summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/dialog_utils.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/dialog_utils.h')
-rw-r--r--umbrello/umbrello/dialog_utils.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/umbrello/umbrello/dialog_utils.h b/umbrello/umbrello/dialog_utils.h
index a414a7a7..0ee2f59a 100644
--- a/umbrello/umbrello/dialog_utils.h
+++ b/umbrello/umbrello/dialog_utils.h
@@ -12,7 +12,7 @@
#ifndef DIALOG_UTILS_H
#define DIALOG_UTILS_H
-#include <qstring.h>
+#include <tqstring.h>
class QGroupBox;
class QGridLayout;
@@ -30,19 +30,19 @@ namespace Dialog_Utils {
/**
* Create a labeled text lineedit widget.
*
* @param containingBox The containing QGroupBox.
* @param layout The QGridLayout to use.
* @param row The row number within the QGridLayout.
* @param label The QLabel object allocated (return value)
* @param labelText The label text.
* @param editField The QLineEdit object allocated (return value)
* @param editFieldText Initialization text in the editField (optional.)
* @return a pointer to the QLineEdit so you can setFocus() if necessary
*/
-QLineEdit* makeLabeledEditField(QGroupBox *containingBox, QGridLayout *layout, int row,
- QLabel * &label, const QString& labelText,
- QLineEdit * &editField,
- const QString& editFieldText = QString::null);
+TQLineEdit* makeLabeledEditField(TQGroupBox *containingBox, TQGridLayout *layout, int row,
+ TQLabel * &label, const TQString& labelText,
+ TQLineEdit * &editField,
+ const TQString& editFieldText = TQString::null);
/**
* Helper function for requesting a name for an UMLWidget using a dialog.
@@ -54,8 +54,8 @@ QLineEdit* makeLabeledEditField(QGroupBox *containingBox, QGridLayout *layout, i
* @param dialogPrompt Prompt of the dialog.
* @param defaultName Default value of the name field.
*/
-void askNameForWidget(UMLWidget * &targetWidget, const QString& dialogTitle,
- const QString& dialogPrompt, const QString& defaultName);
+void askNameForWidget(UMLWidget * &targetWidget, const TQString& dialogTitle,
+ const TQString& dialogPrompt, const TQString& defaultName);
}
@@ -30,19 +30,19 @@ namespace Dialog_Utils {
* Create a labeled text lineedit widget.
*
- * @param containingBox The containing QGroupBox.
- * @param layout The QGridLayout to use.
- * @param row The row number within the QGridLayout.
- * @param label The QLabel object allocated (return value)
+ * @param containingBox The containing TQGroupBox.
+ * @param layout The TQGridLayout to use.
+ * @param row The row number within the TQGridLayout.
+ * @param label The TQLabel object allocated (return value)
* @param labelText The label text.
@@ -30,19 +30,19 @@ namespace Dialog_Utils {
* @param labelText The label text.
- * @param editField The QLineEdit object allocated (return value)
+ * @param editField The TQLineEdit object allocated (return value)
* @param editFieldText Initialization text in the editField (optional.)
@@ -30,19 +30,19 @@ namespace Dialog_Utils {
* @param editFieldText Initialization text in the editField (optional.)
- * @return a pointer to the QLineEdit so you can setFocus() if necessary
+ * @return a pointer to the TQLineEdit so you can setFocus() if necessary
*/